from app import db
from werkzeug.security import generate_password_hash, check_password_hash
from app.config import Config

class User(db.Model):
    __tablename__ = 'user'
    __table_args__ = {'schema': Config.SCHEMA_NAME }

    id = db.Column(db.Integer, primary_key=True)
    username = db.Column(db.String(150), unique=True, nullable=False)
    password_hash = db.Column(db.String(255), nullable=False)
    email = db.Column(db.String(150), unique=True, nullable=True, default='no-reply@example.com')
    current_refresh_token = db.Column(db.String(500), nullable=True)
    # roles = db.relationship('Role', secondary='user_roles', backref=db.backref('users', lazy='dynamic'))

    def set_password(self, password):
        self.password_hash = generate_password_hash(password)

    def check_password(self, password):
        return check_password_hash(self.password_hash, password)

# Role model
class Role(db.Model):
    __tablename__ = 'role'
    __table_args__ = {'schema': Config.SCHEMA_NAME }

    id = db.Column(db.Integer, primary_key=True)
    name = db.Column(db.String(50), unique=True)
    # privileges = db.relationship('Privilege', secondary='role_privileges', backref=db.backref('roles', lazy='dynamic'))

# Privilege model
class Privilege(db.Model):

    __tablename__ = 'privilege'
    __table_args__ = {'schema': Config.SCHEMA_NAME }

    id = db.Column(db.Integer, primary_key=True)
    name = db.Column(db.String(50), unique=True)

# # Association tables
# user_roles = db.Table('user_roles',
#     db.Column('user_id', db.Integer, db.ForeignKey('user.id')),
#     db.Column('role_id', db.Integer, db.ForeignKey('role.id'))
# )

# role_privileges = db.Table('role_privileges',
#     db.Column('role_id', db.Integer, db.ForeignKey('role.id')),
#     db.Column('privilege_id', db.Integer, db.ForeignKey('privilege.id'))
# )